@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Regexp::Pattern;
 
-our $DATE = '2020-05-27'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2020-05-31'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -123,11 +123,12 @@ sub _process_module {
                 }
                 last unless @eg;
                 push @pod, "Examples:\n\n";
+                my $i = 0;
                 for my $eg (@eg) {
-                    if (defined $eg->{summary}) {
-                        require String::PodQuote;
-                        push @pod, String::PodQuote::pod_quote($eg->{summary}), ".\n\n";
-                    }
+                    $i++;
+                    my $summary = $eg->{summary} // "Example #$i";
+                    require String::PodQuote;
+                    push @pod, String::PodQuote::pod_quote($summary), ".\n\n";
 
                     push @pod, " ", dmp($eg->{str}), " =~ re(", dmp("$rp_package\::$patname"), ($eg->{gen_args} ? ", ".dmp($eg->{gen_args}) : ""), "); ";
                     if (ref $eg->{matches} eq 'ARRAY') {
@@ -216,7 +217,7 @@ Pod::Weaver::Plugin::Regexp::Pattern - Plugin to use when building Regexp::Patte
 
 =head1 VERSION
 
-This document describes version 0.006 of Pod::Weaver::Plugin::Regexp::Pattern (from Perl distribution Pod-Weaver-Plugin-Regexp-Pattern), released on 2020-05-27.
+This document describes version 0.007 of Pod::Weaver::Plugin::Regexp::Pattern (from Perl distribution Pod-Weaver-Plugin-Regexp-Pattern), released on 2020-05-31.
 
 =head1 SYNOPSIS
 
